## vX.X.X (yyyy-mm-dd)

### Bug Fixes

* Bypass adding import lines to generated function wrappers when import is not part of the parameterization for the model language driver (as in the case of Matlab).